drop table if exists frota.apontamento_veiculo_gasto_item;
drop table if exists frota.apontamento_veiculo_gasto;
drop table if exists frota.apontamento_veiculo_uso;
drop table if exists frota.agendamento_veiculo_uso;
drop table if exists frota.produto_frota;
drop table if exists frota.categoria_gasto;

ALTER TABLE frota.veiculo
  DROP IF EXISTS vei_modelo,
  DROP IF EXISTS vei_municipio,
  DROP IF EXISTS vei_uf,
  DROP IF EXISTS vei_cor,
  DROP IF EXISTS vei_identificador,
  DROP IF EXISTS vei_renavam,
  DROP IF EXISTS vei_chassi,
  DROP IF EXISTS vei_tipo_combustivel,
  DROP IF EXISTS vei_fk_proprietario_pes_codigo,
  DROP IF EXISTS vei_fk_seguradora_pes_codigo,
  DROP IF EXISTS vei_fk_loe_codigo;
ALTER TABLE frota.veiculo
  ADD vei_identificador VARCHAR(15),
  ADD vei_modelo VARCHAR(25),
  ADD vei_municipio VARCHAR(50),
  ADD vei_uf VARCHAR(2),
  ADD vei_cor VARCHAR(10),
  ADD vei_renavam NUMERIC(11),
  ADD vei_chassi VARCHAR(17),
  ADD vei_tipo_combustivel INTEGER,
  ADD vei_fk_loe_codigo INTEGER,
  ADD vei_fk_proprietario_pes_codigo INTEGER,
  ADD vei_fk_seguradora_pes_codigo INTEGER;

CREATE TABLE frota.produto_frota (
  prfr_codigo        SERIAL PRIMARY KEY,
  prfr_fk_pro_codigo INTEGER,
  prfr_fk_cag_codigo INTEGER,
  prfr_date_insert   TIMESTAMP,
  prfr_user_insert   VARCHAR(30),
  prfr_date_update   TIMESTAMP,
  prfr_user_update   VARCHAR(30)
);

CREATE TABLE frota.apontamento_veiculo_uso (
  avu_codigo                  SERIAL PRIMARY KEY,
  avu_km_inicial              NUMERIC(15, 2),
  avu_km_final                NUMERIC(15, 2),
  avu_observacao              TEXT,
  avu_date_insert             TIMESTAMP,
  avu_user_insert             VARCHAR(30),
  avu_date_update             TIMESTAMP,
  avu_user_update             VARCHAR(30),
  avu_fk_motorista_pes_codigo INTEGER,
  avu_fk_vei_codigo           INTEGER,
  avu_data_hora_uso_inical    TIMESTAMP,
  avu_data_hora_uso_final     TIMESTAMP,
  avu_fk_agu_codigo           INTEGER
);

CREATE TABLE frota.agendamento_veiculo_uso (
  agu_codigo                       SERIAL PRIMARY KEY,
  agu_data_disponibilidade_inicial DATE,
  agu_data_disponibilidade_final   DATE,
  agu_observacao                   TEXT,
  agu_date_insert                  TIMESTAMP,
  agu_user_insert                  VARCHAR(30),
  agu_date_update                  TIMESTAMP,
  agu_user_update                  VARCHAR(30),
  agu_fk_motorista_pes_codigo      INTEGER,
  agu_fk_vei_codigo                INTEGER
);

CREATE TABLE frota.categoria_gasto (
  cag_codigo      SERIAL PRIMARY KEY,
  cag_descricao   VARCHAR(40),
  cag_tipo        INTEGER,
  cag_date_insert TIMESTAMP,
  cag_user_insert VARCHAR(30),
  cag_date_update TIMESTAMP,
  cag_user_update VARCHAR(30)
);

CREATE TABLE frota.apontamento_veiculo_gasto (
  avg_codigo                    SERIAL PRIMARY KEY,
  avg_descricao                 TEXT,
  avg_date_insert               TIMESTAMP,
  avg_user_insert               VARCHAR(30),
  avg_date_update               TIMESTAMP,
  avg_user_update               VARCHAR(30),
  avg_fk_vei_codigo             INTEGER,
  avg_fk_responsavel_pes_codigo INTEGER
);

CREATE TABLE frota.apontamento_veiculo_gasto_item (
  avgi_codigo         SERIAL PRIMARY KEY,
  avgi_quantidade     INTEGER,
  avgi_date_insert    TIMESTAMP,
  avgi_user_insert    VARCHAR(30),
  avgi_date_update    TIMESTAMP,
  avgi_user_update    VARCHAR(30),
  avgi_valor_unitario  NUMERIC(15, 2),
  avgi_fk_avg_codigo  INTEGER,
  avgi_fk_prfr_codigo INTEGER
);

ALTER TABLE frota.veiculo
  ADD CONSTRAINT FK_veiculo_1
FOREIGN KEY (vei_fk_proprietario_pes_codigo)
REFERENCES cadastro.pessoa (pes_codigo)
ON DELETE RESTRICT ON UPDATE RESTRICT;

ALTER TABLE frota.veiculo
  ADD CONSTRAINT FK_veiculo_2
FOREIGN KEY (vei_fk_seguradora_pes_codigo)
REFERENCES cadastro.pessoa (pes_codigo)
ON DELETE RESTRICT ON UPDATE RESTRICT;

ALTER TABLE frota.veiculo
  ADD CONSTRAINT FK_veiculo_3
FOREIGN KEY (vei_fk_loe_codigo)
REFERENCES movimentacao.local_estoque (loe_codigo)
ON DELETE RESTRICT ON UPDATE RESTRICT;

ALTER TABLE frota.produto_frota
  ADD CONSTRAINT FK_produto_frota_1
FOREIGN KEY (prfr_fk_pro_codigo)
REFERENCES produto.produto (pro_codigo)
ON DELETE RESTRICT ON UPDATE RESTRICT;

ALTER TABLE frota.produto_frota
  ADD CONSTRAINT FK_produto_frota_2
FOREIGN KEY (prfr_fk_cag_codigo)
REFERENCES frota.categoria_gasto (cag_codigo)
ON DELETE RESTRICT ON UPDATE RESTRICT;

ALTER TABLE frota.apontamento_veiculo_uso
  ADD CONSTRAINT FK_apontamento_veiculo_uso_1
FOREIGN KEY (avu_fk_motorista_pes_codigo)
REFERENCES cadastro.pessoa (pes_codigo);

ALTER TABLE frota.apontamento_veiculo_uso
  ADD CONSTRAINT FK_apontamento_veiculo_uso_2
FOREIGN KEY (avu_fk_vei_codigo)
REFERENCES frota.veiculo (vei_codigo);

ALTER TABLE frota.apontamento_veiculo_gasto
  ADD CONSTRAINT FK_apontamento_veiculo_gasto_1
FOREIGN KEY (avg_fk_vei_codigo)
REFERENCES frota.veiculo (vei_codigo)
ON DELETE RESTRICT ON UPDATE RESTRICT;

ALTER TABLE frota.apontamento_veiculo_gasto
  ADD CONSTRAINT FK_apontamento_veiculo_gasto_2
FOREIGN KEY (avg_fk_responsavel_pes_codigo)
REFERENCES cadastro.pessoa (pes_codigo)
ON DELETE RESTRICT ON UPDATE RESTRICT;

ALTER TABLE frota.apontamento_veiculo_gasto_item
  ADD CONSTRAINT FK_apontamento_veiculo_gasto_item_1
FOREIGN KEY (avgi_fk_avg_codigo)
REFERENCES frota.apontamento_veiculo_gasto (avg_codigo)
ON DELETE RESTRICT ON UPDATE RESTRICT;

ALTER TABLE frota.apontamento_veiculo_gasto_item
  ADD CONSTRAINT FK_apontamento_veiculo_gasto_item_2
FOREIGN KEY (avgi_fk_prfr_codigo)
REFERENCES frota.produto_frota (prfr_codigo)
ON DELETE RESTRICT ON UPDATE RESTRICT;