<?php

namespace Schaffen\Gef;

use Illuminate\Support\ServiceProvider;
use Illuminate\Routing\Router;
use Schaffen\Gef\Models\AgendamentoVeiculoUso;
use Schaffen\Gef\Models\ApontamentoVeiculoGasto;
use Schaffen\Gef\Models\ApontamentoVeiculoGastoAnexo;
use Schaffen\Gef\Models\ApontamentoVeiculoGastoItem;
use Schaffen\Gef\Models\ApontamentoVeiculoUso;
use Schaffen\Gef\Models\ProdutoFrota;
use Schaffen\Gef\Models\Veiculo;
use Schaffen\Gef\Observers\VeiculoObserver;

class GefServiceProvider extends ServiceProvider
{
   /**
    * Indicates if loading of the provider is deferred.
    *
    * @var bool
    */
   protected $defer = false;

   /**
    * Perform post-registration booting of services.
    *
    * @return void
    */
   public function boot()
   {

      Veiculo::observe( 'Schaffen\\Gef\\Observers\\VeiculoObserver');
      ProdutoFrota::observe( 'Schaffen\\Gef\\Observers\\ProdutoFrotaoObserver');
      AgendamentoVeiculoUso::observe( 'Schaffen\\Gef\\Observers\\AgendamentoVeiculoUsoObserver');
      ApontamentoVeiculoUso::observe( 'Schaffen\\Gef\\Observers\\ApontamentoVeiculoUsoObserver');
      ApontamentoVeiculoGasto::observe( 'Schaffen\\Gef\\Observers\\ApontamentoVeiculoGastoObserver');
      ApontamentoVeiculoGastoItem::observe( 'Schaffen\\Gef\\Observers\\ApontamentoVeiculoGastoItemObserver');
      ApontamentoVeiculoGastoAnexo::observe( 'Schaffen\\Gef\\Observers\\ApontamentoVeiculoGastoAnexoObserver');
      $this->setupRoutes($this->app->router);




   }

   /**
    * Define the routes for the application.
    *
    * @param  \Illuminate\Routing\Router  $router
    * @return void
    */
   public function setupRoutes(Router $router)
   {
      $router->group(['namespace' => 'Schaffen\Gef\Http\Controllers'], function($router)
      {
         require __DIR__ . '/../routes/routes.php';
      });
   }

   /**
    * Register any package services.
    *
    * @return void
    */
   public function register()
   {
      $this->registerGef();

      $this->app->bind(\Schaffen\Gef\Repositories\VeiculoRepository::class, \Schaffen\Gef\Repositories\VeiculoRepositoryEloquent::class);
      $this->app->bind(\Schaffen\Gef\Repositories\ProdutoFrotaRepository::class, \Schaffen\Gef\Repositories\ProdutoFrotaRepositoryEloquent::class);
      $this->app->bind(\Schaffen\Gef\Repositories\CategoriaGastoRepository::class, \Schaffen\Gef\Repositories\CategoriaGastoRepositoryEloquent::class);
      $this->app->bind(\Schaffen\Gef\Repositories\AgendamentoVeiculoUsoRepository::class, \Schaffen\Gef\Repositories\AgendamentoVeiculoUsoRepositoryEloquent::class);//AGENDamento
      $this->app->bind(\Schaffen\Gef\Repositories\ApontamentoVeiculoUsoRepository::class, \Schaffen\Gef\Repositories\ApontamentoVeiculoUsoRepositoryEloquent::class);//APONTamento
      $this->app->bind(\Schaffen\Gef\Repositories\ApontamentoVeiculoGastoRepository::class, \Schaffen\Gef\Repositories\ApontamentoVeiculoGastoRepositoryEloquent::class);
      $this->app->bind(\Schaffen\Gef\Repositories\ApontamentoVeiculoGastoItemRepository::class, \Schaffen\Gef\Repositories\ApontamentoVeiculoGastoItemRepositoryEloquent::class);
      $this->app->bind(\Schaffen\Gef\Repositories\ApontamentoVeiculoGastoAnexoRepository::class, \Schaffen\Gef\Repositories\ApontamentoVeiculoGastoAnexoRepositoryEloquent::class);
   }

   private function registerGef()
   {
      $this->app->bind('gef',function($app){
         return new Gef($app);
      });
   }
}