<?php

namespace Schaffen\Gef\Services;

use App\Http\Utils\SCHArray;
use Schaffen\Gef\Models\ApontamentoVeiculoGastoAnexo;
use Schaffen\Gef\Repositories\ApontamentoVeiculoGastoAnexoRepository;
use Schaffen\Gef\Validators\ApontamentoVeiculoGastoAnexoValidator;
use Prettus\Validator\Exceptions\ValidatorException;

class ApontamentoVeiculoGastoAnexoService
{

   private $repository;
   private $validator;

    public function __construct(ApontamentoVeiculoGastoAnexoRepository $repository, ApontamentoVeiculoGastoAnexoValidator $validator)
    {
       $this->repository = $repository;
       $this->validator = $validator;
    }

   public function updateOrCreate($data, $codigo = null)
   {
      try {

         $attrib = ['avga_codigo' => $codigo];

         $validator_rules = is_numeric($codigo) ? ApontamentoVeiculoGastoAnexoValidator::RULE_UPDATE : ApontamentoVeiculoGastoAnexoValidator::RULE_CREATE;
         $this->validator->with($data)->passesOrFail($validator_rules);
         $this->repository->setPresenter("Schaffen\\Gef\\Presenters\\ApontamentoVeiculoGastoAnexoPresenter");



         $data['fk_ane_codigo'] = $data['id'];
         $data['fk_avg_codigo'] = $data['apontamento_gasto'];

         $data = SCHArray::addPrefix(ApontamentoVeiculoGastoAnexo::$prefix, $data);
         $apontamento_gasto_anexo = $this->repository->updateOrCreate($attrib, $data);

         $response = [
            'status' => true,
            'errors' => '',
            'message' => 'Apontamento de gasto gravado.',
            'data' => $apontamento_gasto_anexo['data'],
            'http_code' => '200'
         ];


         return $response;

      }catch (\Exception $e) {
         throw $e;
      }
   }
}
