<?php

namespace Schaffen\Gef\Services;

use App\Http\Utils\SCHArray;
use Schaffen\Gef\Criterias\AgendamentosDentroPeriodoCriteria;
use Schaffen\Gef\Models\ApontamentoVeiculoUso;
use Schaffen\Gef\Repositories\AgendamentoVeiculoUsoRepository;
use Schaffen\Gef\Repositories\ApontamentoVeiculoUsoRepository;
use Schaffen\Gef\Validators\ApontamentoVeiculoUsoValidator;
use Prettus\Validator\Exceptions\ValidatorException;
use Carbon\Carbon;

class ApontamentoVeiculoUsoService
{

   private $repository;
   private $validator;
   private $agendamento_repository;

   public function __construct(ApontamentoVeiculoUsoRepository $repository, ApontamentoVeiculoUsoValidator $validator, AgendamentoVeiculoUsoRepository $agendamento_repository)
   {
      $this->repository = $repository;
      $this->validator = $validator;
      $this->agendamento_repository = $agendamento_repository;
   }

   public function updateOrCreate($data, $codigo = null)
   {
      try {
         $validator_rules = is_numeric($codigo) ? ApontamentoVeiculoUsoValidator::RULE_UPDATE : ApontamentoVeiculoUsoValidator::RULE_CREATE;
         $this->validator->with($data)->passesOrFail($validator_rules);
         $this->repository->setPresenter("Schaffen\\Gef\\Presenters\\ApontamentoVeiculoUsoPresenter");

         $attrib = ['avu_codigo' => $codigo];

         $data_hora_uso_inicial_carbon = Carbon::createFromFormat('d/m/Y H:i',$data['data_hora_uso_inical']);
         $data_hora_uso_final_carbon = Carbon::createFromFormat('d/m/Y H:i',$data['data_hora_uso_final']);

         $new_data['fk_motorista_pes_codigo'] = $data['motorista'];
         $new_data['fk_vei_codigo'] = $data['veiculo'];
         $new_data['fk_obr_codigo'] = $data['obra'];

         $agendamento = Collect($this->agendamento_repository->getByCriteria(new AgendamentosDentroPeriodoCriteria($data['motorista'],
                                                                                                           $data['veiculo'],
                                                                                                           $data_hora_uso_inicial_carbon,
                                                                                                           $data_hora_uso_final_carbon))['data'])->first();
         if(isset($agendamento)){
            $new_data['fk_agu_codigo'] = $agendamento['codigo'];
         }

         $data = array_merge($new_data, $data);
         $data = SCHArray::addPrefix(ApontamentoVeiculoUso::$prefix, $data);
         $apontamento_uso = $this->repository->updateOrCreate($attrib, $data);

         $response = [
            'status' => true,
            'errors' => '',
            'message' => 'Apontamento de uso do veículo gravado.',
            'data' => $apontamento_uso['data'],
            'http_code' => '200'
         ];


         return $response;

      } catch (ValidatorException $e) {
         return $response = [
            'status' => false,
            'errors' => $e->getMessageBag(),
            'message' => 'Apontamento de uso do veículo gravado.',
            'data' => null,
            'http_code' => '400'
         ];
      }
   }
}
